@@ -1,7 +1,7 @@
 package App::shcompgen;
 
-our $DATE = '2014-12-20'; # DATE
-our $VERSION = '0.08'; # VERSION
+our $DATE = '2015-02-11'; # DATE
+our $VERSION = '0.09'; # VERSION
 
 use 5.010001;
 use strict;
@@ -251,14 +251,14 @@ sub _detect_prog {
             "func.note"=>"hint(completer)",
         }];
     } elsif ($is_perl_script && $content =~
-                 /^\s*(use|require)\s+(Perinci::CmdLine(?:::Any|::Lite)?)\b/m) {
+                 /^\s*(use|require)\s+(Perinci::CmdLine(?:::Any|::Lite|::Classic)?)\b/m) {
         return [200, "OK", 1, {
             "func.completer_command"=> $prog,
             "func.completer_type"=> $2,
             "func.note"=>$2,
         }];
     } elsif ($is_perl_script && $content =~
-                 /^\s*(use|require)\s+(Getopt::Long::Complete)\b/m) {
+                 /^\s*(use|require)\s+(Getopt::Long::(?:Complete|Subcommand))\b/m) {
         return [200, "OK", 1, {
             "func.completer_command"=> $prog,
             "func.completer_type"=> $2,
@@ -617,31 +617,32 @@ App::shcompgen - Generate shell completion scripts
 
 =head1 VERSION
 
-This document describes version 0.08 of App::shcompgen (from Perl distribution App-shcompgen), released on 2014-12-20.
+This document describes version 0.09 of App::shcompgen (from Perl distribution App-shcompgen), released on 2015-02-11.
 
 =head1 FUNCTIONS
 
 
 =head2 generate(%args) -> [status, msg, result, meta]
 
-Generate shell completion scripts for detectable programs.
+{en_US Generate shell completion scripts for detectable programs}.
 
 Arguments ('*' denotes required arguments):
 
 =over 4
 
-=item * B<bash_global_dir> => I<array> (default: ["/usr/share/bash-completion/completions", "/etc/bash_completion.d"])
+=item * B<bash_global_dir> => I<array[str]> (default: ["/usr/share/bash-completion/completions", "/etc/bash_completion.d"])
 
-Directory to put completions scripts.
+{en_US Directory to put completions scripts}.
 
-=item * B<bash_per_user_dir> => I<array>
+=item * B<bash_per_user_dir> => I<array[str]>
 
-Directory to put completions scripts.
+{en_US Directory to put completions scripts}.
 
 =item * B<global> => I<bool>
 
-Use global completions directory.
+{en_US Use global completions directory}.
 
+{en_US 
 Shell has global (system-wide) completions directory as well as per-user. For
 example, in fish the global directory is by default C</etc/fish/completions> and
 the per-user directory is C<~/.config/fish/completions>.
@@ -649,31 +650,36 @@ the per-user directory is C<~/.config/fish/completions>.
 By default, if running as root, the global is chosen. And if running as normal
 user, per-user directory is chosen. Using C<--global> or C<--per-user> overrides
 that and manually select which.
+}
 
-=item * B<prog> => I<array>
+=item * B<prog> => I<array[str]>
 
-Program(s) to generate completion for.
+{en_US Program(s) to generate completion for}.
 
+{en_US 
 Can contain path (e.g. C<../foo>) or a plain word (C<foo>) in which case will be
 searched from PATH.
+}
 
 =item * B<replace> => I<bool>
 
-Replace existing script.
+{en_US Replace existing script}.
 
+{en_US 
 The default behavior is to skip if an existing completion script exists.
+}
 
 =item * B<shell> => I<str>
 
-Override autodetection and select shell manually.
+{en_US Override autodetection and select shell manually}.
 
+{en_US 
 The default is to look at your SHELL environment variable value. If it is
 undefined, the default is C<bash>.
+}
 
 =back
 
-Return value:
-
 Returns an enveloped result (an array).
 
 First element (status) is an integer containing HTTP status code
@@ -683,32 +689,35 @@ First element (status) is an integer containing HTTP status code
 element (meta) is called result metadata and is optional, a hash
 that contains extra information.
 
- (any)
+Return value:  (any)
 
 
 =head2 init(%args) -> [status, msg, result, meta]
 
-Initialize shcompgen.
+{en_US Initialize shcompgen}.
 
+{en_US 
 This subcommand creates the completion directories and initialization shell
 script, as well as run C<generate>.
+}
 
 Arguments ('*' denotes required arguments):
 
 =over 4
 
-=item * B<bash_global_dir> => I<array> (default: ["/usr/share/bash-completion/completions", "/etc/bash_completion.d"])
+=item * B<bash_global_dir> => I<array[str]> (default: ["/usr/share/bash-completion/completions", "/etc/bash_completion.d"])
 
-Directory to put completions scripts.
+{en_US Directory to put completions scripts}.
 
-=item * B<bash_per_user_dir> => I<array>
+=item * B<bash_per_user_dir> => I<array[str]>
 
-Directory to put completions scripts.
+{en_US Directory to put completions scripts}.
 
 =item * B<global> => I<bool>
 
-Use global completions directory.
+{en_US Use global completions directory}.
 
+{en_US 
 Shell has global (system-wide) completions directory as well as per-user. For
 example, in fish the global directory is by default C</etc/fish/completions> and
 the per-user directory is C<~/.config/fish/completions>.
@@ -716,18 +725,19 @@ the per-user directory is C<~/.config/fish/completions>.
 By default, if running as root, the global is chosen. And if running as normal
 user, per-user directory is chosen. Using C<--global> or C<--per-user> overrides
 that and manually select which.
+}
 
 =item * B<shell> => I<str>
 
-Override autodetection and select shell manually.
+{en_US Override autodetection and select shell manually}.
 
+{en_US 
 The default is to look at your SHELL environment variable value. If it is
 undefined, the default is C<bash>.
+}
 
 =back
 
-Return value:
-
 Returns an enveloped result (an array).
 
 First element (status) is an integer containing HTTP status code
@@ -737,31 +747,32 @@ First element (status) is an integer containing HTTP status code
 element (meta) is called result metadata and is optional, a hash
 that contains extra information.
 
- (any)
+Return value:  (any)
 
 
 =head2 list(%args) -> [status, msg, result, meta]
 
-List all shell completion scripts generated by this script.
+{en_US List all shell completion scripts generated by this script}.
 
 Arguments ('*' denotes required arguments):
 
 =over 4
 
-=item * B<bash_global_dir> => I<array> (default: ["/usr/share/bash-completion/completions", "/etc/bash_completion.d"])
+=item * B<bash_global_dir> => I<array[str]> (default: ["/usr/share/bash-completion/completions", "/etc/bash_completion.d"])
 
-Directory to put completions scripts.
+{en_US Directory to put completions scripts}.
 
-=item * B<bash_per_user_dir> => I<array>
+=item * B<bash_per_user_dir> => I<array[str]>
 
-Directory to put completions scripts.
+{en_US Directory to put completions scripts}.
 
 =item * B<detail> => I<bool>
 
 =item * B<global> => I<bool>
 
-Use global completions directory.
+{en_US Use global completions directory}.
 
+{en_US 
 Shell has global (system-wide) completions directory as well as per-user. For
 example, in fish the global directory is by default C</etc/fish/completions> and
 the per-user directory is C<~/.config/fish/completions>.
@@ -769,18 +780,19 @@ the per-user directory is C<~/.config/fish/completions>.
 By default, if running as root, the global is chosen. And if running as normal
 user, per-user directory is chosen. Using C<--global> or C<--per-user> overrides
 that and manually select which.
+}
 
 =item * B<shell> => I<str>
 
-Override autodetection and select shell manually.
+{en_US Override autodetection and select shell manually}.
 
+{en_US 
 The default is to look at your SHELL environment variable value. If it is
 undefined, the default is C<bash>.
+}
 
 =back
 
-Return value:
-
 Returns an enveloped result (an array).
 
 First element (status) is an integer containing HTTP status code
@@ -790,29 +802,30 @@ First element (status) is an integer containing HTTP status code
 element (meta) is called result metadata and is optional, a hash
 that contains extra information.
 
- (any)
+Return value:  (any)
 
 
 =head2 remove(%args) -> [status, msg, result, meta]
 
-Remove shell completion scripts generated by this script.
+{en_US Remove shell completion scripts generated by this script}.
 
 Arguments ('*' denotes required arguments):
 
 =over 4
 
-=item * B<bash_global_dir> => I<array> (default: ["/usr/share/bash-completion/completions", "/etc/bash_completion.d"])
+=item * B<bash_global_dir> => I<array[str]> (default: ["/usr/share/bash-completion/completions", "/etc/bash_completion.d"])
 
-Directory to put completions scripts.
+{en_US Directory to put completions scripts}.
 
-=item * B<bash_per_user_dir> => I<array>
+=item * B<bash_per_user_dir> => I<array[str]>
 
-Directory to put completions scripts.
+{en_US Directory to put completions scripts}.
 
 =item * B<global> => I<bool>
 
-Use global completions directory.
+{en_US Use global completions directory}.
 
+{en_US 
 Shell has global (system-wide) completions directory as well as per-user. For
 example, in fish the global directory is by default C</etc/fish/completions> and
 the per-user directory is C<~/.config/fish/completions>.
@@ -820,25 +833,28 @@ the per-user directory is C<~/.config/fish/completions>.
 By default, if running as root, the global is chosen. And if running as normal
 user, per-user directory is chosen. Using C<--global> or C<--per-user> overrides
 that and manually select which.
+}
 
-=item * B<prog> => I<array>
+=item * B<prog> => I<array[str]>
 
-Program(s) to remove completion script of.
+{en_US Program(s) to remove completion script of}.
 
+{en_US 
 Can contain path (e.g. C<../foo>) or a plain word (C<foo>) in which case will be
 searched from PATH.
+}
 
 =item * B<shell> => I<str>
 
-Override autodetection and select shell manually.
+{en_US Override autodetection and select shell manually}.
 
+{en_US 
 The default is to look at your SHELL environment variable value. If it is
 undefined, the default is C<bash>.
+}
 
 =back
 
-Return value:
-
 Returns an enveloped result (an array).
 
 First element (status) is an integer containing HTTP status code
@@ -848,7 +864,7 @@ First element (status) is an integer containing HTTP status code
 element (meta) is called result metadata and is optional, a hash
 that contains extra information.
 
- (any)
+Return value:  (any)
 
 =head1 HOMEPAGE
 
@@ -872,7 +888,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by perlancar@cpan.org.
+This software is copyright (c) 2015 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
